import { ProxyData } from '../interfaces';
export interface PagePost {
}
export interface PagePostImage extends PagePost {
    caption: string;
    url: string;
}
export interface PagePostText extends PagePost {
    message: string;
    link: string;
}
export declare class Page {
    private pageId;
    private requestData;
    private url;
    private caption;
    private message;
    private link;
    /**
     * @param pageId
     * @param {string} token - Facebook Page Token
     * @param {ProxyData} proxyData - Proxy information if behind proxy
     */
    constructor(pageId: string, token: string, proxyData?: ProxyData);
    /**
     * Sets the url of the image to be added to the page.
     *
     * @param  imageUrl - The url of the image
     * @return {this}
     */
    setImageUrl(imageUrl: string): this;
    /**
     * Sets the caption for the image to be added.
     *
     * @param imageCaption - The caption text of the image
     * @return {this}
     */
    setImageCaption(imageCaption: string): this;
    /**
     * Sets the text for post to be added to the page.
     *
     * @param text
     * @return {this}
     */
    setPostText(text: string): this;
    /**
     * Sets the link of the post to be added to the page.
     * @param postLink - The url to be added to a post on the page
     * @return {this}
     */
    setPostLink(postLink: string): this;
    /**
     * Adds image to Facebook Page.
     *
     * @param {Function} cb - Optional callback for result. If no callback provided will return promise
     * @return
     */
    sendImage(cb?: Function): Promise<unknown>;
    /**
     * Adds posts to Facebook Page.
     * @param {Function} cb - Optional callback for the result. If no callback provided will return promise
     * @return
     */
    sendPost(cb?: Function): Promise<unknown>;
}
