import { ProxyData } from '../';
export interface PageSettings {
    setting_type: string;
}
export interface GreetingSettings extends PageSettings {
    greeting: {
        text?: string;
    };
}
export interface GetStartedSettings extends PageSettings {
    thread_state: string;
    call_to_actions: [{
        payload?: string;
    }];
}
export interface PersistentMenuSettings extends PageSettings {
    thread_state: string;
    persistent_menu: [{
        locale: string;
        call_to_actions?: any[];
    }];
}
/**
 * Class used to set profile specific properties that are visible in Messenger such as Greeting Message, Get Started message
 * and Persistent Menu options.
 */
export declare class Profile {
    private requestData;
    /**
     * @param {string} token - Facebook Page Token
     * @param {ProxyData} proxyData - Proxy information if behind proxy
     */
    constructor(token: string, proxyData?: ProxyData);
    /**
     * Method that sets the Greeting Message that is visible when new user first opens chat with bot before any messages
     * are sent.
     * @param greetingMessage - The message to be set
     * @param cb - Optional callback to get result of setting, promise returned otherwise
     * @return
     */
    setGreetingMessage(greetingMessage: string, cb?: Function): Promise<unknown>;
    /**
     * Method that sets the Get Started button message that is visible when user first opens chat with bot before any messages
     * are sent.
     * @param getStartedPayload - The message to be set
     * @param cb - Optional callback to get result of settings, promise returned otherwise
     * @return
     */
    setGetStartedAction(getStartedPayload: string, cb?: Function): Promise<unknown>;
    /**
     * Method that sets the Persistent Menu options on the left side of the composer that is always visible.
     * @param menuEntries - Options that are to be set.
     * @param cb - Optional callback to get result of settings, promise returned otherwise
     * @return
     */
    setPersistentMenu(menuEntries: any[], cb?: Function): Promise<unknown>;
    private sendConfigurationMessage;
}
