/**
 * Class used to handle the initial verification of a newly added webhook endpoint to Facebook. To be used with the GET
 * route as that is the method used by Facebook for token verification.
 */
export declare class ValidateWebhook {
    private constructor();
    /**
     * Method to validate Facebook Webhook when being run on AWS Lambda when payload is of API GW format and passed in.
     * @param event - The Lambda event object
     * @param {Function} callback - The Lambda callback function
     * @param {string} token - The Facebook token - Optional, will take FB_VERIFICATION_TOKEN if no parameter passed in.
     */
    static validateLambda(event: any, callback: Function, token?: string): void;
    /**
     * Method to validate Facebook Webhook when being run on a traditional server that passes in the request and response
     * objects.
     * @param req - The request object from server
     * @param res - The response object from server
     * @param token - The Facebook token - Optional, will take FB_VERIFICATION_TOKEN if no parameter passed in.
     */
    static validateServer(req: any, res: any, token?: string): void;
    /**
   * Method to validate Facebook message integrity
   * @param xHubSignature - The Signature present in Facebook payload
   * @param applicationSecret - The Facebook application secret - Optional, will take FB_APPLICATION_SECRET if no parameter passed in.
   */
    static validateMessageIntegrity(xHubSignature: string, applicationSecret?: string): boolean;
    private static verifyToken;
}
